@@ -1,6 +1,8 @@
+from typing import Tuple
 from ipey.primitive import Primitive
 import xml.etree.ElementTree as ET
 from collections import defaultdict
+from ipey.helper import convertColor
 import copy
 
 class Page:
@@ -178,7 +180,7 @@ class Page:
 
         return page
 
-    def getLayers(self) -> list:
+    def getLayers(self) -> set:
         layers = set()
         for element in self.Scene:
             layer = element.layer
@@ -188,6 +190,24 @@ class Page:
         
         return layers
 
+    def getColors(self) -> defaultdict(Tuple):
+        colors = dict()
+
+        for element in self.Scene:
+            name = element.getStrokeName()
+            color = element.getStrokeValue()
+
+            if name and color:
+                colors[name] = color
+
+            name = element.getFillName()
+            color = element.getFillValue()
+
+            if name and color:
+                colors[name] = color
+                
+
+        return colors
     '''
     ##################################################
     Overwritten
