@@ -28,7 +28,7 @@ class Writer:
 
     def __init__(self, settings_path = None, styles = []):
         self._options = IpeOptions(settings_path)
-        self.styles = []
+        self.styles = styles
 
     def write(self, pages, path, size, colors):
         ipe = ET.Element('ipe')
