@@ -9,7 +9,7 @@ class Ellipse(Primitive):
         self.co_vertex = cov
 
     def getBB(self):
-        raise NotImplementedError
+        return (self.center, self.center)
 
     def draw(self):
         elem = ET.Element('path')
