@@ -7,7 +7,7 @@ import sys
 
 
 class Glyph(Primitive):
-    def __init__(self, point, type, prototype=None):
+    def __init__(self, point, type='mark/fdisk(sfx)', prototype=None):
         super().__init__(prototype=prototype)
 
         self.x = point[0]
