@@ -15,11 +15,11 @@ class Label(Primitive):
         self.hAlign = 'left'
 
     def getBB(self):
-        return 
+        return (self.anchor, self.anchor)
 
 
     def translate(self, x, y):
-        return 
+        self.anchor = (self.anchor[0] + x, self.anchor[1] + y)
 
 
     def rotate(self, a, pivot=None):
@@ -29,7 +29,7 @@ class Label(Primitive):
         elem = ET.Element('text')
         self.addProperties(elem)
 
-        elem.set('pos', f'{self.anchor[0]} {self.anchor[1]}')
+        elem.set('pos', f'{self.anchor[0]+ self.xP} {self.anchor[1]+ self.yP}')
         elem.set('type', self.type)
         
         if self.isMath:
