@@ -13,13 +13,6 @@ class Minipage(Label):
         self.width = None
         self.style = 'normal'
 
-    def getBB(self):
-        return 
-
-
-    def translate(self, x, y):
-        return 
-
 
     def rotate(self, a, pivot=None):
         return 
